measuretools.get_measure_that_starts_with_container
===================================================

.. autofunction:: abjad.tools.measuretools.get_measure_that_starts_with_container.get_measure_that_starts_with_container
   :noindex:
